
#
# Makefile.PL
# $Id: Makefile.PL 620 2007-12-23 06:08:15Z johnh $
#
# made by module-starter,  8-Nov-07
#

use strict;
use warnings;
use ExtUtils::MakeMaker;

# update moudlarized programs here and in lib/Jdb/Filter/dbpipeline.pm
my @modularized_db_programs = qw(
	dbcol
	dbcolcreate
	dbcolrename
	dbcolstats
	dbcolstatscores
	dbmerge
	dbrow
	dbrowcount
	dbroweval
	dbsort
);   # note that dbpipeline is exclueded because it's not a program
# backwards programs are bin/db* programs that are just for jdb-1.x compatibility
my @backwards_db_programs = qw(
	dbstats 
);
my @standalone_db_programs = qw(
	db2dcliff 
	dbcolcreate 
	dbcoldefine 
	dbcoldiff 
	dbcolhisto 
	dbcolize 
	dbcolmerge 
	dbcolmovingstats 
	dbcolmultiscale 
	dbcolneaten 
	dbcolpercentile 
	dbcolscorrelate 
	dbcolsplittocols 
	dbcolsplittorows 
	dbcolsregression
	dbcolstatscores 
	dbcoltighten 
	dbfilesplit 
	dbfilevalidate
	dbformmail 
	dbjoin 
	dblistize 
	dbmapreduce
	dbmultistats 
	dbrecolize 
	dbrowaccumulate 
	dbrowdiff 
	dbrowenumerate 
	dbrowsplituniq 
	dbrowuniq 
	dbstripcomments 
	dbstripextraheaders 
	dbstripleadingspace
);
my @converters = qw(
    	cgi_to_db
	crl_to_db 
	csv_to_db 
	db_to_html_table 
	db_to_csv 
	dmalloc_to_db 
	ipchain_logs_to_db 
	kitrace_to_db 
	mysql_to_db 
	ns_to_db 
	tabdelim_to_db 
	tcpdump_to_db
);
my @programs_to_install = (@modularized_db_programs, @backwards_db_programs, @standalone_db_programs, @converters);


WriteMakefile(
    NAME                => 'Jdb',
    AUTHOR              => 'John Heidemann <johnh@isi.edu>',
    VERSION_FROM        => 'lib/Jdb.pm',
    ABSTRACT_FROM       => 'lib/Jdb.pm',
    EXE_FILES       => [ map "bin/$_", @programs_to_install ],
    PL_FILES            => {},
    PREREQ_PM => {
        'Test::More' => 0,
        'Text::CSV_XS' => 0,
    },
    dist                => { COMPRESS => 'gzip -9f', SUFFIX => 'gz', },
    clean               => { FILES => 'Jdb-*' },
);

open(MF, ">>Makefile") or die "$0: cannot append to Makefile.\n";

foreach (@modularized_db_programs) {
    print MF "all :: bin/$_\n\n" .
	"bin/$_: lib/Jdb/Filter/$_.pm ./programize_module\n" .
	"\t./programize_module $_ < \$< > \$\@\n\n";
};

print MF <<'END';

#
# standard option propagation:
# (use in development after editing Filter.pm's common documentation)
#
standardoption:
	echo NOT YET DONE


#
# release stuff:
#

README: lib/Jdb.pm
	pod2text < $<  > $@

README.html: lib/Jdb.pm
	pod2html --noindex < $<  > $@

all :: README

SPEC_PREFIX=Jdb
RPM_ARCH=noarch
RPM_PREFIX=perl-Jdb

Jdb.spec: lib/Jdb.pm
	overwrite $@ sed "s/^Version: .*$$/Version: $(VERSION)/"

rpms: $(SPEC_PREFIX).spec Jdb.spec
	cp $(SPEC_PREFIX)-$(VERSION).tar.gz $$HOME/rpmbuild/SOURCES
	cp $(SPEC_PREFIX).spec $$HOME/rpmbuild/SPECS
	( cd $$HOME/rpmbuild; rpmbuild -ba SPECS/$(SPEC_PREFIX).spec; )
	cp $$HOME/rpmbuild/RPMS/$(RPM_ARCH)/$(RPM_PREFIX)-$(VERSION)-1.$(RPM_ARCH).rpm .
	cp $$HOME/rpmbuild/SRPMS/$(RPM_PREFIX)-$(VERSION)-1.src.rpm .

signrpms: 
	rpm --resign $(RPM_PREFIX)-$(VERSION)*.rpm

WEBDIR=/home/johnh/LIB/WWW/SOFTWARE/JDB

release:
	@echo "You should have done \"make dist; make rpms\""
	make signrpms
	cp $(RPM_PREFIX)-$(VERSION)-1.$(RPM_ARCH).rpm $(WEBDIR)
	cp $(RPM_PREFIX)-$(VERSION)-1.src.rpm $(WEBDIR)
	cp $(SPEC_PREFIX)-$(VERSION).tar.gz $(WEBDIR)
	cp README.html $(WEBDIR)/$(SPEC_PREFIX)-$(VERSION)_README.html
	cd $(WEBDIR); svn add $(RPM_PREFIX)-$(VERSION)*.rpm $(SPEC_PREFIX)-$(VERSION).tar.gz $(SPEC_PREFIX)-$(VERSION)_README.txt
	echo "to finish: cd $(WEBDIR); svn commit -m \"release $(RPM_PREFIX)-$(VERSION)\""

END
close (MF);
